# Voice Assistant [![PyPI - Downloads](https://img.shields.io/pypi/dm/voiceassistant?style=flat-square)](https://pypistats.org/packages/voiceassistant)

Open-source voice assistant with emphasis on customizability. Create your own skills and personalize your assistant in a simple YAML configuration. Perfect to use in combination with [Home Assistant](https://www.home-assistant.io/).

## Unique Features
- Say trigger word e.g. "Jarvis" anywhere in a sentence, for example, *"play music, Jarvis"*. Few last seconds of audio input are recoded into memory, so when trigger word is said, pre-recorded audio data is also processed
- Speech is processed continuously while user is speaking which, for certain requests, results in a very fast action/response
- Voice Assistant REST API enables remote control. For example, it can be used to make Voice Assistant say something when Home Assistant automation is triggered
- Define custom skills and extend the nlp "vocubulary" in a simple configuration file

## Available Integrations
[![homepage][1]][2] [![homepage][3]][4] [![homepage][5]][6]

[1]:  /docs/icons/hass.png
[2]:  /docs/integrations/hass.md "Home Assistant"

[3]:  /docs/icons/spotify.png
[4]:  /docs/integrations/spotify.md "Spotify"

[5]:  /docs/icons/respeaker.png
[6]:  /docs/integrations/respeaker.md "ReSpeaker Microphones"

[How they work?](/docs/integrations/how.md)

## Getting Started
- [Installation](/docs/getting-started/installation.md)
- [First time configuration](/docs/getting-started/first-time-config.md)
- [Personalization](/docs/getting-started/personalization.md)
- [Enabling integrations](/docs/getting-started/integrations.md)
- [Creating custom skills](/docs/getting-started/skills.md)



